==> Pyrogram-0.9.1.tar.gz: Pyrogram-0.9.1/pyrogram/client/types/__init__.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .bots import (
    CallbackQuery, ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
    KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
)
from .bots import (
    ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
    KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
)
from .input_media import (
    InputMediaAudio, InputPhoneContact, InputMediaVideo, InputMediaPhoto,
    InputMediaDocument, InputMediaAnimation
)
from .messages_and_media import (
    Audio, Contact, Document, Animation, Location, Photo, PhotoSize,
    Sticker, Venue, Video, VideoNote, Voice, UserProfilePhotos,
    Message, Messages, MessageEntity
)
from .update import Update
from .user_and_chats import (
    Chat, ChatMember, ChatMembers, ChatPhoto,
    Dialog, Dialogs, User, UserStatus
)

==> Pyrogram-0.10.3.tar.gz: Pyrogram-0.10.3/pyrogram/client/types/__init__.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from .bots import (
    CallbackQuery, ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
    KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
)
from .bots import (
    ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
    KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
)
from .input_media import (
    InputMediaAudio, InputPhoneContact, InputMediaVideo, InputMediaPhoto,
    InputMediaDocument, InputMediaAnimation
)
from .messages_and_media import (
    Audio, Contact, Document, Animation, Location, Photo, PhotoSize,
    Sticker, Venue, Video, VideoNote, Voice, UserProfilePhotos,
    Message, Messages, MessageEntity, Poll, PollOption
)
from .user_and_chats import (
    Chat, ChatMember, ChatMembers, ChatPhoto,
    Dialog, Dialogs, User, UserStatus, ChatPreview
)
from .update import StopPropagation
